#
# spec file for package python-web.py
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-web.py
Version:        0.62
Release:        4.3
Summary:        web.py: makes web apps
License:        BSD-3-Clause AND SUSE-Public-Domain
URL:            https://webpy.org/
Source:         https://files.pythonhosted.org/packages/source/w/web.py/web.py-%{version}.tar.gz
BuildRequires:  %{python_module legacy-cgi if %python-base >= 3.13}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cheroot
%if %{python_version_nodots} >= 313
Requires:       python-legacy-cgi
%endif
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module cheroot}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{pythons}
# /SECTION
%python_subpackages

%description
Think about the ideal way to write a web app. Write the code to make it happen.

%prep
%setup -q -n web.py-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#webpy/webpy#712
%pytest -k 'not test_routing'

%files %{python_files}
%{python_sitelib}/*

%changelog
* Thu Nov 21 2024 Dirk Müller <dmueller@suse.com>
- add legacy-cgi for python 3.13 support
* Tue Jan 11 2022 Dirk Müller <dmueller@suse.com>
- add python-rpm-macros
* Wed Jun 30 2021 Matej Cepl <mcepl@suse.com>
- Skip ApplicationTest.test_routing test (reported upstream as gh#webpy/webpy#712)
* Mon Nov  9 2020 Michael Ströder <michael@stroeder.com>
- version update to 0.62:
  * Fixed: application.load() assumes ctx.path will be a latin1 string #687
  * Fixed: can not reset session data to same value as initialized. #683
  * Fixed: can not set session expire time. #655
  * Fixed: not export session store `MemoryStore`.
* Sun Aug  9 2020 Michael Ströder <michael@stroeder.com>
- version update to 0.61:
  * Add python_requires=">=3.5" in setup.py #662
  * Fix incorrect content in MANIFEST.in file.
  * Python-2 support has been completely dropped. Welcome to Python 3.
  * Fixed: session store DiskStore doesn't return correctly if session
  * directory doesn't exist. #652
  * Fixed: incorrect str/bytes type of session data. #644 #645
  * Fixed: db.query("insert... returning") fails to commit. #648 #649
- skip builds for Python 2
* Thu Aug  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not install tests in sitelib directly
* Thu Mar 26 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the test requirements to pull in only what's really needed
- The cheroot is hard requirement by upstream specification so require it
* Wed Mar 25 2020 Michael Ströder <michael@stroeder.com>
- only recommend but not require python-cheroot
* Wed Mar 25 2020 pgajdos@suse.com
- version update to 0.51
  * Update setup.py to pack tests directory and publish to pypi.
  * New session store MemoryStore, used to save a session in memory.
  * Should be useful where there are limited fs writes to the disk, like
    flash memories. #174
  * Fixed: not support samesite=none. #592
  * Fixed Python-3 compatibility issues: #574, #576.
  * Support tuple and set in sqlquote().
  * Drop support for SQL driver pgdb. It was dead, you cannot even find its
    website or download link.
  * Drop support for SQL driver psycopg. The latest version was released in
    2006 (14 years ago), please use psycopg2 instead.
  * Removed function web.safemarkdown. if it's used in your application, you
    can install the Markdown module from pypi
    (https://pypi.org/project/Markdown/), then replace web.safemarkdown() by
    markdown.markdown().
- deleted patches
  - 0001-webpy-572-enable-python-3.8.patch (upstreamed)
- test package
* Thu Mar 12 2020 Michael Ströder <michael@stroeder.com>
- added back-port patch 0001-webpy-572-enable-python-3.8.patch
  for compability with Python 3.8
* Fri Sep 27 2019 Michael Ströder <michael@stroeder.com>
- Updated to 0.40
  * Fixed lots of Python-3 compatibility issues.
  * Drop support for Python 2.3 and 2.4.
  * Allow to get data from PATCH request (fixes #259, tx @kufd)
  * Only store new session data if the data is non-default (fixes #161, tx @shish)
  * Supports `SameSite` cookie attribute (fixes #61 #99 #337)
  * Cookie expire time is now set to same as session `timeout` (fixes #409 #410)
  * Supports url for SQLite database like `sqlite:///mydb.sqlite`,
    `sqlite:////absolute/path/mydb.sqlite` (fixes #209, tx @iamFIREcracker)
  * Allow HTML5 form input elements in `web.form.Input()` (fixes #440, tx @jimgregory)
  * Return body for `NoMethod` error handler (fixes #240, tx @waldhol)
  * Fixed unicode in request url (fixes #461, tx @schneidersoft)
  * Fixed inline comment in Templator which leads to unexpected behavior (fixes #432, tx @lucylqe)
  * Fixed missing exception (ValueError) for socket.inet_pton to be compatible
    with twisted patched `socket.inet_pton` (fixes #464, tx @tclh123)
  * Fixed incorrect order of arguments for sending email with boto (fixes #204, tx @asldevi)
  * Fixed notfound message is not utf-8 charset (fixes #500, tx @by-z)
  * Fixed error in creating pooled PostgresDB with pgdb driver (fixes #255, tx @PriceChild)
  * Fixed: IP address which contains space should not pass validation (fixes #140, tx @chuangbo)
  * Fixed incorrect returned row ids with `multiple_insert()` (fixes #263 #447)
  * Fixed not correctly render the `id` attribute after changed (fixes #339, tx @jimgregory)
* Mon Mar 18 2019 Michael Ströder <michael@stroeder.com>
- Updated to 0.39
  * Fixed a security issue with the form module
  * Fixed a security issue with the db module
* Mon Jan 23 2017 dmueller@suse.com
- fix source url
* Wed Nov 30 2016 michael@stroeder.com
- Updated to 0.38
  * Fixed failing tests in test/session.py when postgres is not installed. (tx Michael Diamond)
  * Fixed an error with Python 2.3 (tx Michael Diamond)
  * web.database now accepts a URL, $DATABASE_URL (fixes #171) (tx Aaron Swartz, we miss you)
  * support port use 'port' as keyword for postgres database with used eith pgdb (tx Sandesh Singh)
  * Fixes to FirebirdDB database (tx Ben Hanna)
  * Added a gaerun method to start application for google app engine (tx Matt Habel)
  * Better error message from `db.multiple_insert` when not all rows have the same keys (tx Ben Hoyt)
  * Allow custom messages for most errors (tx Shaun Sharples)
  * IPv6 support (tx Matthew of Boswell and zamabe)
  * Fixed sending email using Amazon SES (tx asldevi)
  * Fixed handling of long numbers in sqlify. closes #213. (tx cjrolo)
  * Escape HTML characters when emitting API docs. (tx Jeff Zellman)
  * Fixed an inconsistency in form.Dropdown when numbers are used for args and value. (tx Noprianto)
  * Fixed a potential remote exeution risk in `reparam` (tx Adrián Brav)
  * The where clause in db queries can be a dict now
  * Added `first` method to iterbetter
  * Fix to unexpected session when used with MySQL (tx suhashpatil)
  * Change dburl2dict to use urlparse and to support the simple case of just a database name. (tx Jeff Zellman)
  * Support '204 No Content' status code (tx Matteo Landi)
  * Support `451 Unavailable For Legal Reasons` status code(tx Yannik Robin Kettenbach)
  * Updates to documentation (tx goodrone, asldevi)
* Fri Jun 29 2012 cfarrell@suse.com
- Updated to 0.37
  * Fixed datestr issue on Windows -- #155
  * Fixed Python 2.4 compatability issues (tx fredludlow)
  * Fixed error in utils.safewrite (tx shuge) -- #95
  * Allow use of web.data() with app.request() -- #105
  * Fixed an issue with session initializaton (tx beardedprojamz) -- #109
  * Allow custom message on 400 Bad Request (tx patryk) -- #121
  * Made djangoerror work on GAE. -- #80
  * Handle malformatted data in the urls. -- #117
  * Made it easier to stop the dev server -- #100, #122
  * Added support fot customizing cookie_path in session (tx larsga) -- #89
  * Added exception for "415 Unsupported Media" (tx JirkaChadima) -- #145
  * Added GroupedDropdown to support `<optgroup>` tag (tx jzellman) -- #152
  * Fixed failure in embedded interpreter - #87
  * Optimized web.cookies (tx benhoyt) - #148
* Tue Mar 20 2012 cfarrell@suse.com
- license update: SUSE-Public-Domain and BSD-3-Clause
  See e.g. Colin Stewart copyright and license in web/httpserver.py (lines
  22 to 25)
* Thu Mar 15 2012 saschpe@suse.de
- Initial version
